@@ -65,9 +65,6 @@ class PictureModes(Enum):
     natural = b"03"
     hdr = b"04"
     THX = b"06" # unsupported
-    filmmaker = b"\x37" # requires firmware 2.0
-    frame_adapt_hdr2 = b"\x38" # requires firmware 2.0
-    frame_adapt_hdr3 = b"\x39" # requires firmware 2.0
     frame_adapt_hdr = b"0B"
     user1 = b"0C"
     user2 = b"0D"
@@ -78,6 +75,9 @@ class PictureModes(Enum):
     hlg = b"14"
     hdr_plus = b"15"
     pana_pq = b"16"
+    filmmaker = b"17" # requires firmware 2.0
+    frame_adapt_hdr2 = b"18" # requires firmware 2.0
+    frame_adapt_hdr3 = b"19" # requires firmware 2.0
 
 
 class InstallationModes(Enum):
